aboutsummaryrefslogtreecommitdiff
path: root/map.h
diff options
context:
space:
mode:
Diffstat (limited to 'map.h')
-rw-r--r--map.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/map.h b/map.h
index 93672b7..7faa597 100644
--- a/map.h
+++ b/map.h
@@ -58,8 +58,8 @@ void map_to_file_plaintext(char *filename, Map map, size_t width, size_t height,
size_t **file_plaintext_costs(char *filename, size_t width, size_t height);
/* Draw the map. Bet you didn't expect that.
- * path could be NULL to draw a map with no path. So can cursor, frontier and visited */
-void draw_map(Map map, size_t width, size_t height, Position start, Position goal, Position *cursor, Path path, char **visited, PositionPQ *frontier);
+ * path could be NULL to draw a map with no path. So can cursor, frontier and visited and cell_costs */
+void draw_map(Map map, size_t **cell_costs, size_t width, size_t height, Position start, Position goal, Position *cursor, Path path, char **visited, PositionPQ *frontier);
void print_message(size_t height);